@@ -273,11 +273,11 @@ class OpenerDirector(_urllib2_fork.OpenerDirector):
                 blocknum = 0
                 if reporthook:
                     if "content-length" in headers:
-                        size = int(headers["Content-Length"])
+                        size = int(headers["content-length"])
                     reporthook(blocknum, bs, size)
                 while 1:
                     block = fp.read(bs)
-                    if block == "":
+                    if not block:
                         break
                     read += len(block)
                     tfp.write(block)
